==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/MakefileOptions.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Options for Makefiles.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.415Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.MakefileOptions")
@software.amazon.jsii.Jsii.Proxy(MakefileOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MakefileOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.FileBaseOptions {

    /**
     * (experimental) List of targets to build when Make is invoked without specifying any targets.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAll() {
        return null;
    }

    /**
     * (experimental) Rules to include in the Makefile.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<io.github.cdklabs.projen.Rule> getRules() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MakefileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MakefileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MakefileOptions> {
        java.util.List<java.lang.String> all;
        java.util.List<io.github.cdklabs.projen.Rule> rules;
        java.lang.Boolean committed;
        java.lang.Boolean editGitignore;
        java.lang.Boolean executable;
        java.lang.Boolean readonly;

        /**
         * Sets the value of {@link MakefileOptions#getAll}
         * @param all List of targets to build when Make is invoked without specifying any targets.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder all(java.util.List<java.lang.String> all) {
            this.all = all;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getRules}
         * @param rules Rules to include in the Makefile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder rules(java.util.List<? extends io.github.cdklabs.projen.Rule> rules) {
            this.rules = (java.util.List<io.github.cdklabs.projen.Rule>)rules;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getCommitted}
         * @param committed Indicates whether this file should be committed to git or ignored.
         *                  By
         *                  default, all generated files are committed and anti-tamper is used to
         *                  protect against manual modifications.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder committed(java.lang.Boolean committed) {
            this.committed = committed;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getEditGitignore}
         * @param editGitignore Update the project's .gitignore file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder editGitignore(java.lang.Boolean editGitignore) {
            this.editGitignore = editGitignore;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getExecutable}
         * @param executable Whether the generated file should be marked as executable.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder executable(java.lang.Boolean executable) {
            this.executable = executable;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getReadonly}
         * @param readonly Whether the generated file should be readonly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(java.lang.Boolean readonly) {
            this.readonly = readonly;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MakefileOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MakefileOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MakefileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MakefileOptions {
        private final java.util.List<java.lang.String> all;
        private final java.util.List<io.github.cdklabs.projen.Rule> rules;
        private final java.lang.Boolean committed;
        private final java.lang.Boolean editGitignore;
        private final java.lang.Boolean executable;
        private final java.lang.Boolean readonly;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.all = software.amazon.jsii.Kernel.get(this, "all", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.rules = software.amazon.jsii.Kernel.get(this, "rules", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Rule.class)));
            this.committed = software.amazon.jsii.Kernel.get(this, "committed", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.editGitignore = software.amazon.jsii.Kernel.get(this, "editGitignore", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.executable = software.amazon.jsii.Kernel.get(this, "executable", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.readonly = software.amazon.jsii.Kernel.get(this, "readonly", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.all = builder.all;
            this.rules = (java.util.List<io.github.cdklabs.projen.Rule>)builder.rules;
            this.committed = builder.committed;
            this.editGitignore = builder.editGitignore;
            this.executable = builder.executable;
            this.readonly = builder.readonly;
        }

        @Override
        public final java.util.List<java.lang.String> getAll() {
            return this.all;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.Rule> getRules() {
            return this.rules;
        }

        @Override
        public final java.lang.Boolean getCommitted() {
            return this.committed;
        }

        @Override
        public final java.lang.Boolean getEditGitignore() {
            return this.editGitignore;
        }

        @Override
        public final java.lang.Boolean getExecutable() {
            return this.executable;
        }

        @Override
        public final java.lang.Boolean getReadonly() {
            return this.readonly;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAll() != null) {
                data.set("all", om.valueToTree(this.getAll()));
            }
            if (this.getRules() != null) {
                data.set("rules", om.valueToTree(this.getRules()));
            }
            if (this.getCommitted() != null) {
                data.set("committed", om.valueToTree(this.getCommitted()));
            }
            if (this.getEditGitignore() != null) {
                data.set("editGitignore", om.valueToTree(this.getEditGitignore()));
            }
            if (this.getExecutable() != null) {
                data.set("executable", om.valueToTree(this.getExecutable()));
            }
            if (this.getReadonly() != null) {
                data.set("readonly", om.valueToTree(this.getReadonly()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.MakefileOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MakefileOptions.Jsii$Proxy that = (MakefileOptions.Jsii$Proxy) o;

            if (this.all != null ? !this.all.equals(that.all) : that.all != null) return false;
            if (this.rules != null ? !this.rules.equals(that.rules) : that.rules != null) return false;
            if (this.committed != null ? !this.committed.equals(that.committed) : that.committed != null) return false;
            if (this.editGitignore != null ? !this.editGitignore.equals(that.editGitignore) : that.editGitignore != null) return false;
            if (this.executable != null ? !this.executable.equals(that.executable) : that.executable != null) return false;
            return this.readonly != null ? this.readonly.equals(that.readonly) : that.readonly == null;
        }

        @Override
        public final int hashCode() {
            int result = this.all != null ? this.all.hashCode() : 0;
            result = 31 * result + (this.rules != null ? this.rules.hashCode() : 0);
            result = 31 * result + (this.committed != null ? this.committed.hashCode() : 0);
            result = 31 * result + (this.editGitignore != null ? this.editGitignore.hashCode() : 0);
            result = 31 * result + (this.executable != null ? this.executable.hashCode() : 0);
            result = 31 * result + (this.readonly != null ? this.readonly.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/MakefileOptions.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Options for Makefiles.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.121Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.MakefileOptions")
@software.amazon.jsii.Jsii.Proxy(MakefileOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MakefileOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.FileBaseOptions {

    /**
     * (experimental) List of targets to build when Make is invoked without specifying any targets.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAll() {
        return null;
    }

    /**
     * (experimental) Rules to include in the Makefile.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<io.github.cdklabs.projen.Rule> getRules() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MakefileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MakefileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MakefileOptions> {
        java.util.List<java.lang.String> all;
        java.util.List<io.github.cdklabs.projen.Rule> rules;
        java.lang.Boolean committed;
        java.lang.Boolean editGitignore;
        java.lang.Boolean executable;
        java.lang.Boolean marker;
        java.lang.Boolean readonly;

        /**
         * Sets the value of {@link MakefileOptions#getAll}
         * @param all List of targets to build when Make is invoked without specifying any targets.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder all(java.util.List<java.lang.String> all) {
            this.all = all;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getRules}
         * @param rules Rules to include in the Makefile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder rules(java.util.List<? extends io.github.cdklabs.projen.Rule> rules) {
            this.rules = (java.util.List<io.github.cdklabs.projen.Rule>)rules;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getCommitted}
         * @param committed Indicates whether this file should be committed to git or ignored.
         *                  By
         *                  default, all generated files are committed and anti-tamper is used to
         *                  protect against manual modifications.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder committed(java.lang.Boolean committed) {
            this.committed = committed;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getEditGitignore}
         * @param editGitignore Update the project's .gitignore file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder editGitignore(java.lang.Boolean editGitignore) {
            this.editGitignore = editGitignore;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getExecutable}
         * @param executable Whether the generated file should be marked as executable.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder executable(java.lang.Boolean executable) {
            this.executable = executable;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getMarker}
         * @param marker Adds the projen marker to the file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder marker(java.lang.Boolean marker) {
            this.marker = marker;
            return this;
        }

        /**
         * Sets the value of {@link MakefileOptions#getReadonly}
         * @param readonly Whether the generated file should be readonly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(java.lang.Boolean readonly) {
            this.readonly = readonly;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MakefileOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MakefileOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MakefileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MakefileOptions {
        private final java.util.List<java.lang.String> all;
        private final java.util.List<io.github.cdklabs.projen.Rule> rules;
        private final java.lang.Boolean committed;
        private final java.lang.Boolean editGitignore;
        private final java.lang.Boolean executable;
        private final java.lang.Boolean marker;
        private final java.lang.Boolean readonly;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.all = software.amazon.jsii.Kernel.get(this, "all", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.rules = software.amazon.jsii.Kernel.get(this, "rules", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Rule.class)));
            this.committed = software.amazon.jsii.Kernel.get(this, "committed", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.editGitignore = software.amazon.jsii.Kernel.get(this, "editGitignore", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.executable = software.amazon.jsii.Kernel.get(this, "executable", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.marker = software.amazon.jsii.Kernel.get(this, "marker", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.readonly = software.amazon.jsii.Kernel.get(this, "readonly", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.all = builder.all;
            this.rules = (java.util.List<io.github.cdklabs.projen.Rule>)builder.rules;
            this.committed = builder.committed;
            this.editGitignore = builder.editGitignore;
            this.executable = builder.executable;
            this.marker = builder.marker;
            this.readonly = builder.readonly;
        }

        @Override
        public final java.util.List<java.lang.String> getAll() {
            return this.all;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.Rule> getRules() {
            return this.rules;
        }

        @Override
        public final java.lang.Boolean getCommitted() {
            return this.committed;
        }

        @Override
        public final java.lang.Boolean getEditGitignore() {
            return this.editGitignore;
        }

        @Override
        public final java.lang.Boolean getExecutable() {
            return this.executable;
        }

        @Override
        public final java.lang.Boolean getMarker() {
            return this.marker;
        }

        @Override
        public final java.lang.Boolean getReadonly() {
            return this.readonly;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAll() != null) {
                data.set("all", om.valueToTree(this.getAll()));
            }
            if (this.getRules() != null) {
                data.set("rules", om.valueToTree(this.getRules()));
            }
            if (this.getCommitted() != null) {
                data.set("committed", om.valueToTree(this.getCommitted()));
            }
            if (this.getEditGitignore() != null) {
                data.set("editGitignore", om.valueToTree(this.getEditGitignore()));
            }
            if (this.getExecutable() != null) {
                data.set("executable", om.valueToTree(this.getExecutable()));
            }
            if (this.getMarker() != null) {
                data.set("marker", om.valueToTree(this.getMarker()));
            }
            if (this.getReadonly() != null) {
                data.set("readonly", om.valueToTree(this.getReadonly()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.MakefileOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MakefileOptions.Jsii$Proxy that = (MakefileOptions.Jsii$Proxy) o;

            if (this.all != null ? !this.all.equals(that.all) : that.all != null) return false;
            if (this.rules != null ? !this.rules.equals(that.rules) : that.rules != null) return false;
            if (this.committed != null ? !this.committed.equals(that.committed) : that.committed != null) return false;
            if (this.editGitignore != null ? !this.editGitignore.equals(that.editGitignore) : that.editGitignore != null) return false;
            if (this.executable != null ? !this.executable.equals(that.executable) : that.executable != null) return false;
            if (this.marker != null ? !this.marker.equals(that.marker) : that.marker != null) return false;
            return this.readonly != null ? this.readonly.equals(that.readonly) : that.readonly == null;
        }

        @Override
        public final int hashCode() {
            int result = this.all != null ? this.all.hashCode() : 0;
            result = 31 * result + (this.rules != null ? this.rules.hashCode() : 0);
            result = 31 * result + (this.committed != null ? this.committed.hashCode() : 0);
            result = 31 * result + (this.editGitignore != null ? this.editGitignore.hashCode() : 0);
            result = 31 * result + (this.executable != null ? this.executable.hashCode() : 0);
            result = 31 * result + (this.marker != null ? this.marker.hashCode() : 0);
            result = 31 * result + (this.readonly != null ? this.readonly.hashCode() : 0);
            return result;
        }
    }
}
